==> workstyle-src-0.2.2.zip: web/WEB-INF/src/net/yher2/commons/struts/HtmlEscapeHandler.java <==
/**
 * Copyright (c) 2006, yher2.net
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, 
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, 
 *   this list of conditions and the following disclaimer in the documentation 
 *   and/or other materials provided with the distribution.
 * * Neither the name of the nor the names of its contributors may be used to endorse or 
 *   promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */
package net.yher2.commons.struts;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.velocity.app.event.ReferenceInsertionEventHandler;

public class HtmlEscapeHandler implements ReferenceInsertionEventHandler {

	public Object referenceInsert(String reference, Object value) {
		if (StringUtils.equals(reference, "$screen_content")) return value;
		if (reference != null && reference.startsWith("$utils.formatHtmlSimple(")) return value;
		if (reference != null && reference.startsWith("$utils.formatHtmlPlain(")) return value;
		if (reference != null && reference.startsWith("$utils.formatHtmlFull(")) return value;
		if (reference != null && reference.startsWith("$utils.checked(")) return value;
		if (reference != null && reference.startsWith("$utils.selected(")) return value;
		if (reference != null && reference.startsWith("$!utils.formatHtmlSimple(")) return value;
		if (reference != null && reference.startsWith("$!utils.formatHtmlPlain(")) return value;
		if (reference != null && reference.startsWith("$!utils.formatHtmlFull(")) return value;
		if (reference != null && reference.startsWith("$!utils.checked(")) return value;
		if (reference != null && reference.startsWith("$!utils.selected(")) return value;
		if (value == null || value.toString().length() == 0) return "";
		
		String result = StringEscapeUtils.escapeHtml(value.toString());

		return result;
	}

}

==> workstyle-src-0.3.zip: web/WEB-INF/src/net/yher2/commons/struts/HtmlEscapeHandler.java <==
/**
 * Copyright (c) 2006, yher2.net
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, 
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, 
 *   this list of conditions and the following disclaimer in the documentation 
 *   and/or other materials provided with the distribution.
 * * Neither the name of the nor the names of its contributors may be used to endorse or 
 *   promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */
package net.yher2.commons.struts;

import org.apache.commons.lang.CustomStringEscapeUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.velocity.app.event.ReferenceInsertionEventHandler;

public class HtmlEscapeHandler implements ReferenceInsertionEventHandler {

	public Object referenceInsert(String reference, Object value) {
		if (StringUtils.equals(reference, "$screen_content")) return value;
		if (reference != null && reference.startsWith("$utils.raw(")) return value;
		if (reference != null && reference.startsWith("$utils.formatHtmlSimple(")) return value;
		if (reference != null && reference.startsWith("$utils.formatHtmlPlain(")) return value;
		if (reference != null && reference.startsWith("$utils.formatHtmlFull(")) return value;
		if (reference != null && reference.startsWith("$utils.checked(")) return value;
		if (reference != null && reference.startsWith("$utils.selected(")) return value;
		if (reference != null && reference.startsWith("$!utils.raw(")) return value;
		if (reference != null && reference.startsWith("$!utils.formatHtmlSimple(")) return value;
		if (reference != null && reference.startsWith("$!utils.formatHtmlPlain(")) return value;
		if (reference != null && reference.startsWith("$!utils.formatHtmlFull(")) return value;
		if (reference != null && reference.startsWith("$!utils.checked(")) return value;
		if (reference != null && reference.startsWith("$!utils.selected(")) return value;
		if (value == null || value.toString().length() == 0) return "";
		
		String result = CustomStringEscapeUtils.escapeHtml(value.toString());

		return result;
	}

}
